.. currentmodule:: pycvcam.core

pycvcam.core.TransformComposition
=================================

.. contents:: Table of Contents
   :local:
   :depth: 2
   :backlinks: top

.. note::

    See the main :class:`pycvcam.core.Transform` documentation for more details on how to use transformations.

TransformComposition Class
---------------------------

.. autoclass:: TransformComposition


Performing transformations with TransformComposition objects
--------------------------------------------------------------

.. autosummary::
   :toctree: ../_autosummary/

   TransformComposition._transform
   TransformComposition._inverse_transform